@@ -5,12 +5,12 @@ _ZLIB_ARCHIVE="zlib-1.2.11.tar.xz"
 _EXPAT_ARCHIVE="expat-2.2.0.tar.bz2"
 _LIBTOOL_ARCHIVE="libtool-2.4.6.tar.xz"
 
-_LIBICONV_ARCHIVE="libiconv-1.14.tar.gz"
+_LIBICONV_ARCHIVE="libiconv-1.15.tar.gz"
 _LIBXML2_ARCHIVE="libxml2-2.9.4.tar.gz"
 _GETTEXT_ARCHIVE="gettext-0.19.8.1.tar.xz"
 
-_LIBCURL_ARCHIVE="curl-7.52.1.tar.bz2"
-_OPENSSL_ARCHIVE="openssl-1.0.2j.tar.gz"
+_LIBCURL_ARCHIVE="curl-7.54.0.tar.bz2"
+_OPENSSL_ARCHIVE="openssl-1.0.2l.tar.gz"
 
 _LIBISDS_ARCHIVE="libisds-0.10.6.tar.xz"
 _LIBISDS_ARCHIVE_PATCHES=" \
