@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2015 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -614,163 +614,48 @@ cli_error findDatabox(const QMap <QString, QVariant> &map, QString &errmsg)
 	qDebug() << CLI_PREFIX << "find info about databox from username"
 	    <<  username;
 
-	struct isds_ctx *session;
-	struct isds_PersonName *personName = NULL;
-	struct isds_Address *address = NULL;
-	struct isds_DbOwnerInfo *ownerInfo = NULL;
-	struct isds_list *boxes = NULL;
-	isds_DbType dbType;
+	enum TaskSearchOwner::BoxType boxType = TaskSearchOwner::BT_OVM;
 
 	/* set type of search databox */
 	QString dbTypeTmp = map.value("dbType").toString();
 	if (dbTypeTmp == DB_FO) {
-		dbType = DBTYPE_FO;
+		boxType = TaskSearchOwner::BT_FO;
 	} else if (dbTypeTmp == DB_PFO) {
-		dbType = DBTYPE_PFO;
+		boxType = TaskSearchOwner::BT_PFO;
 	} else if (dbTypeTmp == DB_PO) {
-		dbType = DBTYPE_PO;
+		boxType = TaskSearchOwner::BT_PO;
 	} else {
-		dbType = DBTYPE_OVM;
+		boxType = TaskSearchOwner::BT_OVM;
 	}
 
-	/* set person firt and last name */
-	personName = isds_PersonName_create(
-	    map.contains("pnFirstName") ?
-	        map.value("pnFirstName").toString() : QString(),
-	    QString(),
-	    map.contains("pnLastName") ?
-	        map.value("pnLastName").toString() : QString(),
-	    QString());
-	if (NULL == personName) {
-		errmsg = "Error while create find databox request";
-		isds_PersonName_free(&personName);
-		return CLI_ERROR;
-	}
-	/* set PSC */
-	address = isds_Address_create(QString(), QString(), QString(),
-	    QString(),
-	    map.contains("adZipCode") ?
-	         map.value("adZipCode").toString() : QString(),
-	    QString());
-	if (NULL == address) {
-		errmsg = "Error while create find databox request";
-		isds_PersonName_free(&personName);
-		isds_Address_free(&address);
+	TaskSearchOwner::SoughtOwnerInfo soughtInfo(
+	    map.contains("dbID") ? map.value("dbID").toString() : QString(),
+	    boxType,
+	    map.contains("ic") ? map.value("ic").toString() : QString(),
+	    map.contains("pnFirstName") ? map.value("pnFirstName").toString() : QString(),
+	    map.contains("pnLastName") ? map.value("pnLastName").toString() : QString(),
+	    map.contains("firmName") ? map.value("firmName").toString() : QString(),
+	    map.contains("adZipCode") ? map.value("adZipCode").toString() : QString());
+
+	QList<TaskSearchOwner::BoxEntry> foundBoxes;
+	QString errMsg;
+	QString longErrMsg;
+	enum TaskSearchOwner::Result result = TaskSearchOwner::isdsSearch(
+	    username, soughtInfo, foundBoxes, errMsg, longErrMsg);
+
+	if (TaskSearchOwner::SO_SUCCESS != result) {
+		errmsg = longErrMsg;
 		return CLI_ERROR;
 	}
 
-	ownerInfo = isds_DbOwnerInfo_createConsume(
-	    map.contains("dbID") ?
-	        map.value("dbID").toString() : QString(),
-	    dbType,
-	    map.contains("ic") ?
-	        map.value("ic").toString() : QString(),
-	    personName,
-	    map.contains("firmName") ?
-	        map.value("firmName").toString() : QString(),
-	    NULL, address, QString(), QString(),
-	    QString(), QString(), QString(), 0, false, false);
-	if (NULL != ownerInfo) {
-		personName = NULL;
-		address = NULL;
-	} else {
-		errmsg = "Error while create find databox request";
-		isds_PersonName_free(&personName);
-		isds_Address_free(&address);
-		isds_DbOwnerInfo_free(&ownerInfo);
-		return CLI_ERROR;
-	}
-
-	int status = TaskSearchOwner::isdsSearch(username, ownerInfo, &boxes);
-	isds_DbOwnerInfo_free(&ownerInfo);
-
-	session = globIsdsSessions.session(username);
-	if (NULL == session) {
-		errmsg = "Error while create find databox request";
-		isds_PersonName_free(&personName);
-		isds_Address_free(&address);
-		isds_DbOwnerInfo_free(&ownerInfo);
-		return CLI_ERROR;
-	}
-
-	if (IE_SUCCESS != status) {
-		errmsg = isdsLongMessage(session);
-		isds_PersonName_free(&personName);
-		isds_Address_free(&address);
-		isds_DbOwnerInfo_free(&ownerInfo);
-		return CLI_ERROR;
-	}
-
-	struct isds_list *box;
-	box = boxes;
-
-	while (0 != box) {
-		isds_DbOwnerInfo *item = (isds_DbOwnerInfo *) box->data;
+	foreach (const TaskSearchOwner::BoxEntry &entry, foundBoxes) {
 		QStringList contact;
-		contact.clear();
-		contact.append(item->dbID);
-		QString name;
-
-		if ((item->dbType != NULL) && (*item->dbType == DBTYPE_FO)) {
-			name = QString(item->personName->pnFirstName) +
-			    " " + QString(item->personName->pnLastName);
-		} else if ((item->dbType != NULL) &&
-		    (*item->dbType == DBTYPE_PFO)) {
-			QString firmName = item->firmName;
-			if (firmName.isEmpty() || firmName == " ") {
-				name = QString(item->personName->pnFirstName) +
-				    " " + QString(item->personName->pnLastName);
-			} else {
-				name = item->firmName;
-			}
-		} else {
-			name = item->firmName;
-		}
-
-		QString address,street,adNumberInStreet,adNumberInMunicipality;
-		if (NULL != item->address) {
-
-			street = item->address->adStreet;
-			adNumberInStreet = item->address->adNumberInStreet;
-			adNumberInMunicipality =
-			     item->address->adNumberInMunicipality;
-
-			if (street.isEmpty() || street == " ") {
-				address = item->address->adCity;
-			} else {
-				address = street;
-				if (adNumberInStreet.isEmpty() ||
-				    adNumberInStreet == " ") {
-					address += + " " +
-					    adNumberInMunicipality +
-					    ", " + QString(item->address->adCity);
-				} else if (adNumberInMunicipality.isEmpty() ||
-				    adNumberInMunicipality == " ") {
-					address += + " " +
-					    adNumberInStreet +
-					    ", " + QString(item->address->adCity);
-				} else {
-					address += + " "+
-					    adNumberInMunicipality
-					    + "/" +
-					    adNumberInStreet +
-					", " + QString(item->address->adCity);
-				}
-			}
-
-			contact.append("|" + name + "|" + address + "|" +
-			     QString(item->address->adZipCode)) ;
-			printDataToStdOut(contact);
-
-		}
-		box = box->next;
+		contact.append(entry.id);
+		contact.append("|" + entry.name + "|" + entry.address +
+		    "|" + entry.zipCode);
+		printDataToStdOut(contact);
 	}
 
-	isds_PersonName_free(&personName);
-	isds_Address_free(&address);
-	isds_DbOwnerInfo_free(&ownerInfo);
-	isds_list_free(&boxes);
-
 	return CLI_SUCCESS;
 }
 
@@ -1141,11 +1026,12 @@ cli_error createAndSendMsg(const QMap <QString, QVariant> &map,
 			/* Store new message into database. */
 			qint64 dmId =
 			    QString(sent_message->envelope->dmID).toLongLong();
-			const QString dbIDSender = globAccountDbPtr->dbId(
-			    map["username"].toString() + "___True");
-			const QString dmSender = globAccountDbPtr->
-			    senderNameGuess(map["username"].toString() +
-			    "___True");
+			const QString acntDbKey(AccountDb::keyFromLogin(
+			    map["username"].toString()));
+			const QString dbIDSender(
+			    globAccountDbPtr->dbId(acntDbKey));
+			const QString dmSender(
+			    globAccountDbPtr->senderNameGuess(acntDbKey));
 			QDateTime deliveryTime = timevalToDateTime(
 			    sent_message->envelope->dmDeliveryTime);
 			MessageDb *messageDb =
