@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2015 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,59 +21,44 @@
  * the two.
  */
 
+#include <QMimeDatabase>
+#include <QMimeType>
 
 #include "common.h"
 #include "src/io/isds_sessions.h"
 #include "src/log/log.h"
 
-
 const QString dateTimeDisplayFormat("dd.MM.yyyy HH:mm:ss");
 const QString dateDisplayFormat("dd.MM.yyyy");
 
-QLocale programLocale;
-
-
-/* ========================================================================= */
-/*
- * Translates message type to text.
- */
-const QString dmTypeToText(const QString &dmType)
-/* ========================================================================= */
+void addAttachmentToEmailMessage(QString &message, const QString &attachName,
+    const QByteArray &base64, const QString &boundary)
 {
-	if (dmType.size() != 1) {
-		return QString();
-	}
+	const QString newLine("\n"); /* "\r\n" ? */
 
-	switch (dmType[0].toLatin1()) {
-	case 'K':
-		return QObject::tr("Postal data message");
-		break;
-	case 'I':
-		return QObject::tr("Initializing postal data message");
-		break;
-	case 'O':
-		return QObject::tr("Reply postal data message");
-		break;
-	case 'X':
-		return QObject::tr(
-		    "Initializing postal data message - expired");
-		break;
-	case 'Y':
-		return QObject::tr("Initializing postal data message - used");
-		break;
-	default:
-		return QString();
-		break;
+	QMimeDatabase mimeDb;
+
+	QMimeType mimeType(
+	    mimeDb.mimeTypeForData(QByteArray::fromBase64(base64)));
+
+	message += newLine;
+	message += "--" + boundary + newLine;
+	message += "Content-Type: " + mimeType.name() + "; charset=UTF-8;" + newLine +
+	    " name=\"" + attachName +  "\"" + newLine;
+	message += "Content-Transfer-Encoding: base64" + newLine;
+	message += "Content-Disposition: attachment;" + newLine +
+	    " filename=\"" + attachName + "\"" + newLine;
+
+	for (int i = 0; i < base64.size(); ++i) {
+		if ((i % 60) == 0) {
+			message += newLine;
+		}
+		message += base64.at(i);
 	}
+	message += newLine;
 }
 
-
-/* ========================================================================= */
-/*
- * Translates author type to text.
- */
 const QString authorTypeToText(const QString &authorType)
-/* ========================================================================= */
 {
 	if ("PRIMARY_USER" == authorType) {
 		/* Opravnena osoba nebo likvidator. */
@@ -95,95 +80,145 @@ const QString authorTypeToText(const QString &authorType)
 	}
 }
 
-
-/* ========================================================================= */
-/*
- * Returns message status description.
- */
-const QString msgStatusToText(int status)
-/* ========================================================================= */
+int base64RealSize(const QByteArray &b64)
 {
-	switch (status) {
-	case 1:
-		/* Zprava byla podana (vznikla v ISDS). */
-		return QObject::tr("Message has been submitted (has been created in ISDS)");
-		break;
-	case 2:
-		/*
-		 * Datová zprava vcetne pisemnosti podepsana casovym razitkem.
-		 */
-		return QObject::tr("Data message including its attachments signed with time-stamp.");
-		break;
-	case 3:
-		/*
-		 * Zprava neprosla AV kontrolou; nakazena pisemnost je smazana;
-		 * konecny stav zpravy pred smazanim.
-		 */
-		return QObject::tr("Message did not pass through AV check; "
-		    "infected paper deleted; final status before deletion.");
-		break;
-	case 4:
-		/* Zprava dodana do ISDS (zapsan cas dodani). */
-		return QObject::tr("Message handed into ISDS "
-		    "(delivery time recorded).");
-		break;
-	case 5:
-		/*
-		 * Uplynulo 10 dnu od dodani verejne zpravy, ktera dosud nebyla
-		 * dorucena prihlasenim (predpoklad dorucení fikci u neOVM DS);
-		 * u komercni zpravy nemuze tento stav nastat.
-		 */
-		return QObject::tr("10 days have passed since the delivery of "
-		    "the public message which has not been accepted by "
-		    "logging-in (assumption of delivery by fiction in nonOVM "
-		    "DS); this state cannot occur for commercial messages.");
-		break;
-	case 6:
-		/*
-		 * Osoba opravnena cist tuto zpravu se prihlasila - dodana
-		 * zprava byla dorucena.",
-		 */
-		return QObject::tr("A person authorised to read this message "
-		    "has logged in -- delivered message has been accepted.");
-		break;
-	case 7:
-		/* Zprava byla prectena (na portale nebo akci ESS). */
-		return QObject::tr("Message has been read (on the portal or "
-		    "by ESS action).");
-		break;
-	case 8:
-		/*
-		 * Zprava byla oznacena jako nedorucitelna, protoze DS adresata
-		 * byla zpetne znepristupnena.
-		 */
-		return QObject::tr("Message marked as undeliverable because "
-		    "the target DS has been made inaccessible.");
-		break;
-	case 9:
-		/*
-		 * Obsah zpravy byl smazan, obalka zpravy vcetne hashu
-		 * presunuta do archivu.
-		 */
-		return QObject::tr("Message content deleted, envelope "
-		    "including hashes has been moved into archive.");
-		break;
-	case 10:
-		/* Zprava je v Datovem trezoru. */
-		return QObject::tr("Message resides in data vault.");
-		break;
-	default:
-		return QString();
-		break;
+	int b64size = b64.size();
+	int cnt = 0;
+	if (b64size >= 3) {
+		for (int i = 1; i <= 3; ++i) {
+			if ('=' == b64[b64size - i]) {
+				++cnt;
+			}
+		}
 	}
+	return b64size * 3 / 4 - cnt;
 }
 
+QString convertAttachmentType(int value)
+{
+	if (value == FILEMETATYPE_MAIN) return "main";
+	else if (value == FILEMETATYPE_ENCLOSURE) return "encl";
+	else if (value == FILEMETATYPE_SIGNATURE) return "sign";
+	else if (value == FILEMETATYPE_META) return "meta";
+	else return "";
+}
+
+QString convertDbTypeToString(int value)
+{
+	if (value == DBTYPE_SYSTEM) return "SYSTEM";
+	else if (value == DBTYPE_OVM) return "OVM";
+	else if (value == DBTYPE_OVM_NOTAR) return "OVM_NOTAR";
+	else if (value == DBTYPE_OVM_EXEKUT) return "OVM_EXEKUT";
+	else if (value == DBTYPE_OVM_REQ) return "OVM_REQ";
+	else if (value == DBTYPE_PO) return "PO";
+	else if (value == DBTYPE_PO_ZAK) return "PO_ZAK";
+	else if (value == DBTYPE_PO_REQ) return "PO_REQ";
+	else if (value == DBTYPE_PFO) return "PFO";
+	else if (value == DBTYPE_PFO_ADVOK) return "PFO_ADVOK";
+	else if (value == DBTYPE_PFO_DANPOR) return "PFO_DANPOR";
+	else if (value == DBTYPE_PFO_INSSPR) return "PFO_INSSPR";
+	else if (value == DBTYPE_FO) return "FO";
+	else return "";
+}
+
+int convertDbTypeToInt(QString value)
+{
+	if (value == "OVM") return DBTYPE_OVM;
+	else if (value == "OVM_NOTAR") return DBTYPE_OVM_NOTAR;
+	else if (value == "OVM_EXEKUT") return DBTYPE_OVM_EXEKUT;
+	else if (value == "OVM_REQ") return DBTYPE_OVM_REQ;
+	else if (value == "PO") return DBTYPE_PO;
+	else if (value == "PO_ZAK") return DBTYPE_PO_ZAK;
+	else if (value == "PO_REQ") return DBTYPE_PO_REQ;
+	else if (value == "PFO") return DBTYPE_PFO;
+	else if (value == "PFO_ADVOK") return DBTYPE_PFO_ADVOK;
+	else if (value == "PFO_DANPOR") return DBTYPE_PFO_DANPOR;
+	else if (value == "PFO_INSSPR") return DBTYPE_PFO_INSSPR;
+	else if (value == "FO") return DBTYPE_FO;
+	else return DBTYPE_SYSTEM;
+}
+
+QString convertEventTypeToString(int value)
+{
+	if (value == EVENT_ACCEPTED_BY_RECIPIENT) return "EV4: ";
+	else if (value == EVENT_ACCEPTED_BY_FICTION) return "EV2: ";
+	else if (value == EVENT_UNDELIVERABLE) return "EV3: ";
+	else if (value == EVENT_COMMERCIAL_ACCEPTED) return "EV1: ";
+	else if (value == EVENT_ENTERED_SYSTEM) return "EV0: ";
+	else if (value == EVENT_DELIVERED) return "EV5: ";
+	else if (value == EVENT_PRIMARY_LOGIN) return "EV11: ";
+	else if (value == EVENT_ENTRUSTED_LOGIN) return "EV12: ";
+	else if (value == EVENT_SYSCERT_LOGIN) return "EV13: ";
+	else if (value == EVENT_UKNOWN) return "";
+	else return "";
+}
+
+QString convertHashAlg(int value)
+{
+	if (value == HASH_ALGORITHM_MD5) return "MD5";
+	else if (value == HASH_ALGORITHM_SHA_1) return "SHA-1";
+	else if (value == HASH_ALGORITHM_SHA_224) return "SHA-224";
+	else if (value == HASH_ALGORITHM_SHA_256) return "SHA-256";
+	else if (value == HASH_ALGORITHM_SHA_384) return "SHA-384";
+	else if (value == HASH_ALGORITHM_SHA_512) return "SHA-512";
+	else return "";
+}
+
+int convertHashAlg2(QString value)
+{
+	if (value == "MD5") return HASH_ALGORITHM_MD5;
+	else if (value == "SHA-1") return HASH_ALGORITHM_SHA_1;
+	else if (value == "SHA-224") return HASH_ALGORITHM_SHA_224;
+	else if (value == "SHA-256") return HASH_ALGORITHM_SHA_256;
+	else if (value == "SHA-384") return HASH_ALGORITHM_SHA_384;
+	else if (value == "SHA-512") return HASH_ALGORITHM_SHA_512;
+	else return 0;
+}
+
+int convertHexToDecIndex(int value)
+{
+	if (value == MESSAGESTATE_SENT) return 1;
+	else if (value == MESSAGESTATE_STAMPED) return 2;
+	else if (value == MESSAGESTATE_INFECTED) return 3;
+	else if (value == MESSAGESTATE_DELIVERED) return 4;
+	else if (value == MESSAGESTATE_SUBSTITUTED) return 5;
+	else if (value == MESSAGESTATE_RECEIVED) return 6;
+	else if (value == MESSAGESTATE_READ) return 7;
+	else if (value == MESSAGESTATE_UNDELIVERABLE) return 8;
+	else if (value == MESSAGESTATE_REMOVED) return 9;
+	else if (value == MESSAGESTATE_IN_SAFE) return 10;
+	else return 0;
+}
+
+QString convertSenderDbTypesToString(int value)
+{
+	/* System ISDS */
+	if (value == DBTYPE_SYSTEM) return QObject::tr("System ISDS");
+	/* OVM */
+	else if (value == DBTYPE_OVM) return QObject::tr("Public authority");
+	/* PO */
+	else if (value == DBTYPE_PO) return QObject::tr("Legal person");
+	/* PFO (OSVC) */
+	else if (value == DBTYPE_PFO) return QObject::tr("Self-employed person");
+	/* FO */
+	else if (value == DBTYPE_FO) return QObject::tr("Natural person");
+	/* unknown */
+	else return "";
+}
+
+QString convertSenderTypeToString(int value)
+{
+	if (value == SENDERTYPE_PRIMARY) return "PRIMARY_USER";
+	else if (value == SENDERTYPE_ENTRUSTED) return "ENTRUSTED_USER";
+	else if (value == SENDERTYPE_ADMINISTRATOR) return "ADMINISTRATOR";
+	else if (value == SENDERTYPE_OFFICIAL) return "OFFICIAL";
+	else if (value == SENDERTYPE_VIRTUAL) return "VIRTUAL";
+	else if (value == SENDERTYPE_OFFICIAL_CERT) return "OFFICIAL_CERT";
+	else if (value == SENDERTYPE_LIQUIDATOR) return "LIQUIDATOR";
+	else return "";
+}
 
-/* ========================================================================= */
-/*
- * Return privilegs as html string from number representation.
- */
 QString convertUserPrivilsToString(int userPrivils)
-/* ========================================================================= */
 {
 	QString privStr;
 	const QString sepPref("<li>- "), sepSuff("</li>");
@@ -241,125 +276,7 @@ QString convertUserPrivilsToString(int userPrivils)
 	return privStr;
 }
 
-
-/* ========================================================================= */
-/*
- * Convert hex to dec number
- */
-int convertHexToDecIndex(int value)
-/* ========================================================================= */
-{
-	if (value == MESSAGESTATE_SENT) return 1;
-	else if (value == MESSAGESTATE_STAMPED) return 2;
-	else if (value == MESSAGESTATE_INFECTED) return 3;
-	else if (value == MESSAGESTATE_DELIVERED) return 4;
-	else if (value == MESSAGESTATE_SUBSTITUTED) return 5;
-	else if (value == MESSAGESTATE_RECEIVED) return 6;
-	else if (value == MESSAGESTATE_READ) return 7;
-	else if (value == MESSAGESTATE_UNDELIVERABLE) return 8;
-	else if (value == MESSAGESTATE_REMOVED) return 9;
-	else if (value == MESSAGESTATE_IN_SAFE) return 10;
-	else return 0;
-}
-
-
-/* ========================================================================= */
-/*
- * Convert hash algorithm to string
- */
-QString convertHashAlg(int value)
-/* ========================================================================= */
-{
-	if (value == HASH_ALGORITHM_MD5) return "MD5";
-	else if (value == HASH_ALGORITHM_SHA_1) return "SHA-1";
-	else if (value == HASH_ALGORITHM_SHA_224) return "SHA-224";
-	else if (value == HASH_ALGORITHM_SHA_256) return "SHA-256";
-	else if (value == HASH_ALGORITHM_SHA_384) return "SHA-384";
-	else if (value == HASH_ALGORITHM_SHA_512) return "SHA-512";
-	else return "";
-}
-
-
-/* ========================================================================= */
-/*
- * Convert hash algorithm to int
- */
-int convertHashAlg2(QString value)
-/* ========================================================================= */
-{
-	if (value == "MD5") return HASH_ALGORITHM_MD5;
-	else if (value == "SHA-1") return HASH_ALGORITHM_SHA_1;
-	else if (value == "SHA-224") return HASH_ALGORITHM_SHA_224;
-	else if (value == "SHA-256") return HASH_ALGORITHM_SHA_256;
-	else if (value == "SHA-384") return HASH_ALGORITHM_SHA_384;
-	else if (value == "SHA-512") return HASH_ALGORITHM_SHA_512;
-	else return 0;
-}
-
-
-
-/* ========================================================================= */
-/*
- * Convert type of attachment files
- */
-QString convertAttachmentType(int value)
-/* ========================================================================= */
-{
-	if (value == FILEMETATYPE_MAIN) return "main";
-	else if (value == FILEMETATYPE_ENCLOSURE) return "encl";
-	else if (value == FILEMETATYPE_SIGNATURE) return "sign";
-	else if (value == FILEMETATYPE_META) return "meta";
-	else return "";
-}
-
-/* ========================================================================= */
-/*
- * Convert type of author to string
- */
-QString convertSenderTypeToString(int value)
-/* ========================================================================= */
-{
-	if (value == SENDERTYPE_PRIMARY) return "PRIMARY_USER";
-	else if (value == SENDERTYPE_ENTRUSTED) return "ENTRUSTED_USER";
-	else if (value == SENDERTYPE_ADMINISTRATOR) return "ADMINISTRATOR";
-	else if (value == SENDERTYPE_OFFICIAL) return "OFFICIAL";
-	else if (value == SENDERTYPE_VIRTUAL) return "VIRTUAL";
-	else if (value == SENDERTYPE_OFFICIAL_CERT) return "OFFICIAL_CERT";
-	else if (value == SENDERTYPE_LIQUIDATOR) return "LIQUIDATOR";
-	else return "";
-}
-
-
-/* ========================================================================= */
-/*
- * Convert type of databox to string
- */
-QString convertDbTypeToString(int value)
-/* ========================================================================= */
-{
-	if (value == DBTYPE_SYSTEM) return "SYSTEM";
-	else if (value == DBTYPE_OVM) return "OVM";
-	else if (value == DBTYPE_OVM_NOTAR) return "OVM_NOTAR";
-	else if (value == DBTYPE_OVM_EXEKUT) return "OVM_EXEKUT";
-	else if (value == DBTYPE_OVM_REQ) return "OVM_REQ";
-	else if (value == DBTYPE_PO) return "PO";
-	else if (value == DBTYPE_PO_ZAK) return "PO_ZAK";
-	else if (value == DBTYPE_PO_REQ) return "PO_REQ";
-	else if (value == DBTYPE_PFO) return "PFO";
-	else if (value == DBTYPE_PFO_ADVOK) return "PFO_ADVOK";
-	else if (value == DBTYPE_PFO_DANPOR) return "PFO_DANPOR";
-	else if (value == DBTYPE_PFO_INSSPR) return "PFO_INSSPR";
-	else if (value == DBTYPE_FO) return "FO";
-	else return "";
-}
-
-
-/* ========================================================================= */
-/*
- * Convert type of user to string
- */
 const QString & convertUserTypeToString(int value)
-/* ========================================================================= */
 {
 	static const QString pu("PRIMARY_USER"), eu("ENTRUSTED_USER"),
 	    a("ADMINISTRATOR"), l("LIQUIDATOR"), ou("OFFICIAL_USER"),
@@ -377,78 +294,72 @@ const QString & convertUserTypeToString(int value)
 	}
 }
 
-
-/* ========================================================================= */
-/*
- * Return sender databox type as string from number representation.
- */
-QString convertSenderDbTypesToString(int value)
-/* ========================================================================= */
+void createEmailMessage(QString &message, const QString &subj,
+    const QString &boundary)
 {
-	/* System ISDS */
-	if (value == DBTYPE_SYSTEM) return QObject::tr("System ISDS");
-	/* OVM */
-	else if (value == DBTYPE_OVM) return QObject::tr("Public authority");
-	/* PO */
-	else if (value == DBTYPE_PO) return QObject::tr("Legal person");
-	/* PFO (OSVC) */
-	else if (value == DBTYPE_PFO) return QObject::tr("Self-employed person");
-	/* FO */
-	else if (value == DBTYPE_FO) return QObject::tr("Natural person");
-	/* unknown */
-	else return "";
+	message.clear();
+
+	const QString newLine("\n"); /* "\r\n" ? */
+
+	/* Rudimentary header. */
+	message += "Subject: " + subj + newLine;
+	message += "MIME-Version: 1.0" + newLine;
+	message += "Content-Type: multipart/mixed;" + newLine +
+	    " boundary=\"" + boundary + "\"" + newLine;
+
+	/* Body. */
+	message += newLine;
+	message += "--" + boundary + newLine;
+	message += "Content-Type: text/plain; charset=UTF-8" + newLine;
+	message += "Content-Transfer-Encoding: 8bit" + newLine;
+
+	message += newLine;
+	message += "-- " + newLine; /* Must contain the space. */
+	message += " " + QObject::tr("Created using Datovka") + " " VERSION "." + newLine;
+	message += " <URL: " DATOVKA_HOMEPAGE_URL ">" + newLine;
 }
 
-
-/* ========================================================================= */
-/*
- * Convert type of databox to int
- */
-int convertDbTypeToInt(QString value)
-/* ========================================================================= */
+const QString dmTypeToText(const QString &dmType)
 {
-	if (value == "OVM") return DBTYPE_OVM;
-	else if (value == "OVM_NOTAR") return DBTYPE_OVM_NOTAR;
-	else if (value == "OVM_EXEKUT") return DBTYPE_OVM_EXEKUT;
-	else if (value == "OVM_REQ") return DBTYPE_OVM_REQ;
-	else if (value == "PO") return DBTYPE_PO;
-	else if (value == "PO_ZAK") return DBTYPE_PO_ZAK;
-	else if (value == "PO_REQ") return DBTYPE_PO_REQ;
-	else if (value == "PFO") return DBTYPE_PFO;
-	else if (value == "PFO_ADVOK") return DBTYPE_PFO_ADVOK;
-	else if (value == "PFO_DANPOR") return DBTYPE_PFO_DANPOR;
-	else if (value == "PFO_INSSPR") return DBTYPE_PFO_INSSPR;
-	else if (value == "FO") return DBTYPE_FO;
-	else return DBTYPE_SYSTEM;
+	if (dmType.size() != 1) {
+		return QString();
+	}
+
+	switch (dmType[0].toLatin1()) {
+	case 'K':
+		return QObject::tr("Postal data message");
+		break;
+	case 'I':
+		return QObject::tr("Initializing postal data message");
+		break;
+	case 'O':
+		return QObject::tr("Reply postal data message");
+		break;
+	case 'X':
+		return QObject::tr(
+		    "Initializing postal data message - expired");
+		break;
+	case 'Y':
+		return QObject::tr("Initializing postal data message - used");
+		break;
+	default:
+		return QString();
+		break;
+	}
 }
 
-/* ========================================================================= */
-/*
- * Convert event type to string
- */
-QString convertEventTypeToString(int value)
-/* ========================================================================= */
+void finishEmailMessage(QString &message, const QString &boundary)
 {
-	if (value == EVENT_ACCEPTED_BY_RECIPIENT) return "EV4: ";
-	else if (value == EVENT_ACCEPTED_BY_FICTION) return "EV2: ";
-	else if (value == EVENT_UNDELIVERABLE) return "EV3: ";
-	else if (value == EVENT_COMMERCIAL_ACCEPTED) return "EV1: ";
-	else if (value == EVENT_ENTERED_SYSTEM) return "EV0: ";
-	else if (value == EVENT_DELIVERED) return "EV5: ";
-	else if (value == EVENT_PRIMARY_LOGIN) return "EV11: ";
-	else if (value == EVENT_ENTRUSTED_LOGIN) return "EV12: ";
-	else if (value == EVENT_SYSCERT_LOGIN) return "EV13: ";
-	else if (value == EVENT_UKNOWN) return "";
-	else return "";
+	const QString newLine("\n"); /* "\r\n" ? */
+	message += newLine + "--" + boundary + "--" + newLine;
 }
 
+QString fromBase64(const QString &base64)
+{
+	return QString::fromUtf8(QByteArray::fromBase64(base64.toUtf8()));
+}
 
-/* ========================================================================= */
-/*
- * Convert event type to string
- */
 QString getdbStateText(int value)
-/* ========================================================================= */
 {
 	switch (value) {
 	case DBSTATE_ACCESSIBLE:
@@ -482,70 +393,12 @@ QString getdbStateText(int value)
 	}
 }
 
-
-/* ========================================================================= */
-/*
- * Converts base64 encoded string into plain text.
- */
-QString fromBase64(const QString &base64)
-/* ========================================================================= */
-{
-	return QString::fromUtf8(QByteArray::fromBase64(base64.toUtf8()));
-}
-
-
-/* ========================================================================= */
-/*!
- * @brief Converts string into base64.
- */
-QString toBase64(const QString &plain)
-/* ========================================================================= */
-{
-	return QString::fromUtf8(plain.toUtf8().toBase64());
-}
-
-/* ========================================================================= */
-int base64RealSize(const QByteArray &b64)
-/* ========================================================================= */
-{
-	int b64size = b64.size();
-	int cnt = 0;
-	if (b64size >= 3) {
-		for (int i = 1; i <= 3; ++i) {
-			if ('=' == b64[b64size - i]) {
-				++cnt;
-			}
-		}
-	}
-	return b64size * 3 / 4 - cnt;
-}
-
-/* ========================================================================= */
-/*
- * True if selected account is WebDatovka (MojeId) account.
- */
-bool isWebDatovkaAccount(const QString &userName)
-/* ========================================================================= */
-{
-	return userName.contains(DB_MOJEID_NAME_PREFIX);
-}
-
-/* ========================================================================= */
-/*
- * Get/create WebDatovka (MojeId) username.
- */
 QString getWebDatovkaUsername(const QString &userId, const QString &accountId)
-/* ========================================================================= */
 {
 	return DB_MOJEID_NAME_PREFIX + userId + "-" + accountId;
 }
 
-/* ========================================================================= */
-/*
- * Get account id from username of WebDatovka account.
- */
 int getWebDatovkaAccountId(const QString &userName)
-/* ========================================================================= */
 {
 	if (!userName.contains(DB_MOJEID_NAME_PREFIX)) {
 		return -1;
@@ -555,12 +408,7 @@ int getWebDatovkaAccountId(const QString &userName)
 	return aID.toInt();
 }
 
-/* ========================================================================= */
-/*
- * Get user id from username of WebDatovka account.
- */
 int getWebDatovkaUserId(const QString &userName)
-/* ========================================================================= */
 {
 	if (!userName.contains(DB_MOJEID_NAME_PREFIX)) {
 		return -1;
@@ -569,12 +417,7 @@ int getWebDatovkaUserId(const QString &userName)
 	return uID.toInt();
 }
 
-/* ========================================================================= */
-/*
- * Get name prefix of tag database from username (WebDatovka).
- */
 QString getWebDatovkaTagDbPrefix(const QString &userName)
-/* ========================================================================= */
 {
 	if (!userName.contains(DB_MOJEID_NAME_PREFIX)) {
 		return QString();
@@ -582,3 +425,161 @@ QString getWebDatovkaTagDbPrefix(const QString &userName)
 
 	return DB_MOJEID_NAME_PREFIX + userName.split("-").at(1);
 }
+
+bool isWebDatovkaAccount(const QString &userName)
+{
+	return userName.contains(DB_MOJEID_NAME_PREFIX);
+}
+
+bool isValidDatabaseFileName(QString inDbFileName,
+    QString &dbUserName, QString &dbYear, bool &dbTestingFlag, QString &errMsg)
+{
+	QStringList fileNameParts;
+	bool ret = false;
+	errMsg = "";
+	dbUserName = "";
+	dbYear = "";
+
+	if (inDbFileName.contains("___")) {
+		// get username from filename
+		fileNameParts = inDbFileName.split("_");
+		if (fileNameParts.isEmpty() || fileNameParts.count() <= 1) {
+			errMsg = QObject::tr("File '%1' does not contain a valid "
+			    "database filename.").arg(inDbFileName);
+			return ret;
+		}
+		if (fileNameParts[0].isEmpty() ||
+		    fileNameParts[0].length() != 6) {
+			errMsg = QObject::tr("File '%1' does not contain a valid "
+			    "username in the database filename.").arg(inDbFileName);
+			return ret;
+		}
+		dbUserName = fileNameParts[0];
+
+		// get year from filename
+		if (fileNameParts[1].isEmpty()) {
+			dbYear = "";
+		} else if (fileNameParts[1] == "inv") {
+			dbYear = fileNameParts[1];
+		} else if (fileNameParts[1].length() == 4) {
+			dbYear = fileNameParts[1];
+		} else {
+			errMsg = QObject::tr("File '%1' does not contain valid "
+			    "year in the database filename.").arg(inDbFileName);
+			dbYear = "";
+			return ret;
+		}
+
+		// get testing flag from filename
+		fileNameParts = inDbFileName.split(".");
+		if (fileNameParts.isEmpty()) {
+			errMsg = QObject::tr("File '%1' does not contain valid "
+			    "database filename.").arg(inDbFileName);
+			return ret;
+		}
+		fileNameParts = fileNameParts[0].split("___");
+		if (fileNameParts.isEmpty()) {
+			errMsg = QObject::tr("File '%1' does not contain "
+			    "valid database filename.").arg(inDbFileName);
+			return ret;
+		}
+
+		if (fileNameParts[1] == "1") {
+			dbTestingFlag = true;
+		} else if (fileNameParts[1] == "0") {
+			dbTestingFlag = false;
+		} else {
+			errMsg = QObject::tr("File '%1' does not contain a valid "
+			    "account type flag or filename has wrong format.").arg(inDbFileName);
+			dbTestingFlag = false;
+			return ret;
+		}
+	} else {
+		errMsg = QObject::tr("File '%1' does not contain a valid message "
+		    "database or filename has wrong format.").arg(inDbFileName);
+		return ret;
+	}
+
+	return true;
+}
+
+const QString msgStatusToText(int status)
+{
+	switch (status) {
+	case 1:
+		/* Zprava byla podana (vznikla v ISDS). */
+		return QObject::tr("Message has been submitted (has been created in ISDS)");
+		break;
+	case 2:
+		/*
+		 * Datová zprava vcetne pisemnosti podepsana casovym razitkem.
+		 */
+		return QObject::tr("Data message including its attachments signed with time-stamp.");
+		break;
+	case 3:
+		/*
+		 * Zprava neprosla AV kontrolou; nakazena pisemnost je smazana;
+		 * konecny stav zpravy pred smazanim.
+		 */
+		return QObject::tr("Message did not pass through AV check; "
+		    "infected paper deleted; final status before deletion.");
+		break;
+	case 4:
+		/* Zprava dodana do ISDS (zapsan cas dodani). */
+		return QObject::tr("Message handed into ISDS "
+		    "(delivery time recorded).");
+		break;
+	case 5:
+		/*
+		 * Uplynulo 10 dnu od dodani verejne zpravy, ktera dosud nebyla
+		 * dorucena prihlasenim (predpoklad dorucení fikci u neOVM DS);
+		 * u komercni zpravy nemuze tento stav nastat.
+		 */
+		return QObject::tr("10 days have passed since the delivery of "
+		    "the public message which has not been accepted by "
+		    "logging-in (assumption of acceptance through fiction in non-OVM "
+		    "DS); this state cannot occur for commercial messages.");
+		break;
+	case 6:
+		/*
+		 * Osoba opravnena cist tuto zpravu se prihlasila - dodana
+		 * zprava byla dorucena.",
+		 */
+		return QObject::tr("A person authorised to read this message "
+		    "has logged in -- delivered message has been accepted.");
+		break;
+	case 7:
+		/* Zprava byla prectena (na portale nebo akci ESS). */
+		return QObject::tr("Message has been read (on the portal or "
+		    "by ESS action).");
+		break;
+	case 8:
+		/*
+		 * Zprava byla oznacena jako nedorucitelna, protoze DS adresata
+		 * byla zpetne znepristupnena.
+		 */
+		return QObject::tr("Message marked as undeliverable because "
+		    "the target DS has been made inaccessible.");
+		break;
+	case 9:
+		/*
+		 * Obsah zpravy byl smazan, obalka zpravy vcetne hashu
+		 * presunuta do archivu.
+		 */
+		return QObject::tr("Message content deleted, envelope "
+		    "including hashes has been moved into archive.");
+		break;
+	case 10:
+		/* Zprava je v Datovem trezoru. */
+		return QObject::tr("Message resides in data vault.");
+		break;
+	default:
+		return QString();
+		break;
+	}
+}
+
+QString toBase64(const QString &plain)
+{
+	return QString::fromUtf8(plain.toUtf8().toBase64());
+}
