@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@
 
 #include "src/common.h"
 #include "src/io/account_db.h"
+#include "src/io/exports.h"
 #include "src/io/message_db.h"
 #include "src/io/message_db_set.h"
 #include "src/gui/dlg_import_zfo.h"
@@ -90,24 +91,6 @@ public:
 	static
 	MessageDbSet *accountDbSet(const QString &userName, MainWindow *mw);
 
-	/*!
-	 * @brief Get data about logged in user and his box.
-	 */
-	static
-	bool getOwnerInfoFromLogin(const QString &userName);
-
-	/*!
-	 * @brief Get information about password expiration date.
-	 */
-	static
-	bool getPasswordInfoFromLogin(const QString &userName);
-
-	/*!
-	 * @brief Get data about logged in user.
-	 */
-	static
-	bool getUserInfoFromLogin(const QString &userName);
-
 	/*!
 	 * @brief Get account list from Webdatovka.
 	 */
@@ -116,11 +99,30 @@ public:
 
 protected:
 	/*!
-	 * Check if some worker is working on the background and show
+	 * @brief Check if some worker is working on the background and show
 	 * dialog if user want to close application
 	 */
-	void closeEvent(QCloseEvent *event);
+	virtual
+	void closeEvent(QCloseEvent *event) Q_DECL_OVERRIDE;
 
+	/*!
+	 * @brief Store original window position on window maximisation.
+	 */
+	virtual
+	void moveEvent(QMoveEvent *event) Q_DECL_OVERRIDE;
+
+	/*!
+	 * @brief Store original window size on window maximisation.
+	 */
+	virtual
+	void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
+
+	/*!
+	 * @brief Check window geometry, adjust size if window is too large for
+	 *     desktop..
+	 */
+	virtual
+	void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
 
 public slots:
 
@@ -168,6 +170,12 @@ private slots:
 	    int direction, int result, const QString &errDesc,
 	    bool add, int rt, int rn, int st, int sn);
 
+	/*!
+	 * @brief Collects information about import status.
+	 */
+	void collectImportZfoStatus(const QString &fileName, int result,
+	    const QString &resultDesc);
+
 	/*!
 	 * @brief Performs action depending on message send outcome.
 	 */
@@ -454,12 +462,12 @@ private slots:
 	/*!
 	 * @brief Shows the application preferences dialog.
 	 */
-	void applicationPreferences(void);
+	void showPreferencesDialog(void);
 
 	/*!
-	 * @brief Add account action and dialog.
+	 * @brief Show add new account dialog.
 	 */
-	void addNewAccount(void);
+	void showAddNewAccountDialog(void);
 
 	/*!
 	 * @brief Add mojeID account action and dialog.
@@ -494,7 +502,7 @@ private slots:
 	/*!
 	 * @brief Proxy settings dialogue.
 	 */
-	void proxySettings(void);
+	void showProxySettingsDialog(void);
 
 	/*!
 	 * @brief Move selected account up.
@@ -514,7 +522,7 @@ private slots:
 	/*!
 	 * @brief View signature details.
 	 */
-	void showSignatureDetails(void);
+	void showSignatureDetailsDialog(void);
 
 	/*!
 	 * @brief Export selected message into ZFO files.
@@ -580,64 +588,27 @@ private slots:
 	/*!
 	 * @brief View message from file dialog.
 	 */
-	void viewMessageFromZFO(void);
+	void showViewMessageFromZFODialog(void);
 
 	/*!
 	 * @brief Export correspondence overview dialog.
 	 */
-	void exportCorrespondenceOverview(void);
+	void showExportCorrespondenceOverviewDialog(void);
 
 	/*!
 	 * @brief Show dialog with settings of import ZFO file(s) into database.
 	 */
 	void showImportZFOActionDialog(void);
 
-	/*!
-	 * @brief Create ZFO file(s) list for import into database.
-	 */
-	void createZFOListForImport(enum ImportZFODialog::ZFOtype zfoType,
-	    enum ImportZFODialog::ZFOaction importType, bool checkOnServer);
-
-	/*!
-	 * @brief Collects information about import status.
-	 */
-	void collectImportZfoStatus(const QString &fileName, int result,
-	    const QString &resultDesc);
-
-	/*!
-	 * @brief Create account info list for ZFO files import into database.
-	 *
-	 * @note The user if going to be prompted about missing password.
-	 *
-	 * @param[in] activeOnly Whether to list only active accounts.
-	 * @return List of accounts.
-	 */
-	QList<Task::AccountDescr> createAccountInfoForZFOImport(
-	    bool activeOnly);
-
-	/*!
-	 * @brief Prepare import ZFO file(s) into database by ZFO type.
-	 */
-	void prepareZFOImportIntoDatabase(const QStringList &files,
-	    enum ImportZFODialog::ZFOtype zfoType, bool authenticate);
-
-	/*!
-	 * @brief Show ZFO import notification dialog with results of import.
-	 */
-	void showImportZfoResultDialogue(int filesCnt,
-	    const QList<QPair<QString,QString>> &successFilesList,
-	    const QList<QPair<QString,QString>> &existFilesList,
-	    const QList<QPair<QString,QString>> &errorFilesList);
-
 	/*!
 	 * @brief About application dialog.
 	 */
-	void aboutApplication(void);
+	void showAboutApplicationDialog(void);
 
 	/*!
 	 * @brief Show help/manual in a internet browser.
 	 */
-	void showHelp(void);
+	void showAppHelpInTheBrowser(void);
 
 	/*!
 	 * @brief Go to homepage.
@@ -704,7 +675,7 @@ private slots:
 	/*!
 	 * @brief Show advanced message search dialogue.
 	 */
-	void showMsgAdvancedSearchDlg(void);
+	void showMsgAdvancedSearchDialog(void);
 
 	/*!
 	 * @brief On message dialogue exit.
@@ -729,13 +700,13 @@ private slots:
 	/*!
 	 * @brief Store last add attachment path.
 	 */
-	void doActionAfterSentMsgSlot(const QString &userName,
+	void storeAttachmentPath(const QString &userName,
 	    const QString &lastDir);
 
 	/*!
 	 * @brief Show tags manager dialog for tags settings.
 	 */
-	void showTagDlg(void);
+	void showTagDialog(void);
 
 	/*!
 	 * @brief Add/delete tags to/from selected messages.
@@ -751,6 +722,12 @@ private slots:
 	    const QString &token, QString userName, QString pwd, QString otp,
 	    bool syncALL, const QString &certPath);
 
+	/*!
+	 * @brief Show information about import message results.
+	 */
+	void showImportMessageResults(const QString &userName,
+	    const QStringList &errImportList, int totalMsgs, int importedMsgs);
+
 private:
 
 	QTimer m_timerSyncAccounts;
@@ -805,39 +782,6 @@ private:
 	static
 	void viewSelectedMessageViaFilter(QObject *mwPtr);
 
-	/*!
-	 * @brief Export message into ZFO file dialogue.
-	 */
-	void exportMessageAsZFO(const QString &attachPath,
-	    const QString &userName, MessageDb::MsgId msgId, bool askLocation);
-
-	/*!
-	 * @brief Export delivery information as ZFO file dialogue.
-	 */
-	void exportDeliveryInfoAsZFO(const QString &attachPath,
-	    const QString &attachFileName, const QString &formatString,
-	    const QString &userName, MessageDb::MsgId msgId,
-	    bool askLocation);
-
-	/*!
-	 * @brief Export delivery information as PDF file dialogue.
-	 */
-	void exportDeliveryInfoAsPDF(const QString &attachPath,
-	    const QString &attachFileName, const QString &formatString,
-	    const QString &userName, MessageDb::MsgId msgId, bool askLocation);
-
-	/*!
-	 * @brief Export selected message envelope as PDF file dialogue.
-	 */
-	void exportMessageEnvelopeAsPDF(const QString &attachPath,
-	    const QString &userName, MessageDb::MsgId msgId, bool askLocation);
-
-	/*!
-	 * @brief Export selected message envelope as PDF and attachment files.
-	 */
-	void exportMessageEnvelopeAttachments(const QString &attachPath,
-	    const QString &userName, MessageDb::MsgId msgId, bool askLocation);
-
 	/*!
 	 * @brief Set info status bar from worker.
 	 */
@@ -850,12 +794,6 @@ private:
 	void postDownloadSelectedMessageAttachments(const QString &userName,
 	    qint64 dmId);
 
-	/*!
-	 * @brief Generates file path where sto store attachment into.
-	 */
-	QString attachmentFilePath(const QString &userName,
-	    const MessageDb::MsgId &msgId, QModelIndex attIdx);
-
 	/*!
 	 * @brief Save attachment identified by indexes to file.
 	 */
@@ -941,9 +879,11 @@ private:
 	void setAttachmentActionVisibility(int numSelected) const;
 
 	/*!
-	 * @brief Open send message dialog and send message.
+	 * @brief Show send message dialog and send message(s).
+	 *
+	 * @param[in] action Defines send action (new,reply,forward,template).
 	 */
-	void openSendMessageDialog(int action);
+	void showSendMessageDialog(int action);
 
 	/*!
 	 * @brief Active/Inactive account menu and buttons in the mainwindow.
@@ -1013,7 +953,7 @@ private:
 	/*!
 	 * @brief Saves account export paths.
 	 */
-	void storeExportPath(void);
+	void storeExportPath(const QString &userName);
 
 	/*!
 	 * @brief Store geometry to settings.
@@ -1174,53 +1114,6 @@ private:
 	void exportExpirMessagesToZFO(const QString &userName,
 	    const QList<MessageDb::MsgId> &expirMsgIds);
 
-	/*!
-	 * @brief Import of messages from database to selected account.
-	 */
-	void doMsgsImportFromDatabase(const QStringList &dbFileList,
-	    const QString &userName);
-
-	/*!
-	 * @brief Split database filename into mandatory entries.
-	 *
-	 * @param[in] inDbFileName - input database file name.
-	 * @param[out] dbUserName - username entry.
-	 * @paran[out] dbYear - year entry if exists or NULL.
-	 * @paran[out] dbTestingFlag - true if account is testing or false
-	 * @paran[out] errMsg - error message to user
-	 * @return true if database filename is correct
-	 */
-	bool isValidDatabaseFileName(QString inDbFileName, QString &dbUserName,
-	    QString &dbYear, bool &dbTestingFlag, QString &errMsg);
-
-	/*!
-	 * @brief Split message database into new databases
-	 * contain messages for single years.
-	 * @param[in] userName - username of account.
-	 * @return true if success
-	 */
-	bool splitMsgDbByYears(const QString &userName);
-
-	/*!
-	 * @brief Show error message box
-	 * @param[in] msgTitle - title of message box.
-	 * @param[in] msgText - main text of message box.
-	 * @param[in] msgInformativeText - info text of message box.
-	 */
-	void showErrMessageBox(const QString &msgTitle,
-	    const QString &msgText, const QString &msgInformativeText);
-
-	/*!
-	 * @brief Set back original database path if error during
-	 *    database splitting
-	 * @param[in] dbset - MessageDbSet.
-	 * @param[in] dbDir - origin database dir.
-	 * @param[in] userName - username of account.
-	 * @return true if success
-	 */
-	bool setBackOriginDb(MessageDbSet *dbset, const QString &dbDir,
-	    const QString &userName);
-
 	/*!
 	 * @brief Show dialog for webdatovka account
 	 *        that action is not implemented.
@@ -1238,6 +1131,21 @@ private:
 	 */
 	bool existsAnotherMojeIdAccountWithSameUserId(const QString &userName);
 
+	/*!
+	 * @brief Export selected messages to disk.
+	 *
+	 * @param[in] expFileType - export file type.
+	 */
+	void doExportOfSelectedFiles(enum Exports::ExportFileType expFileType);
+
+	/*
+	 * @brief Show ZFO import notification dialog with results of import.
+	 */
+	void showImportZfoResultDialogue(int filesCnt,
+	    const QList<QPair<QString,QString>> &successFilesList,
+	    const QList<QPair<QString,QString>> &existFilesList,
+	    const QList<QPair<QString,QString>> &errorFilesList);
+
 	QString m_confDirName; /*!< Configuration directory location. */
 	QString m_confFileName; /*!< Configuration file location. */
 
@@ -1246,10 +1154,9 @@ private:
 	                              * configuration file.
 	                              */
 	SortFilterProxyModel m_messageListProxyModel; /*!<
-	                                                * Used for message
-	                                                * sorting and
-	                                                * filtering.
-	                                                */
+	                                               * Used for message
+	                                               * sorting and filtering.
+	                                               */
 
 	QTimer m_messageMarker; /*!< Used for marking messages as read. */
 	qint64 m_lastSelectedMessageId; /*!< Id of the last selected message. */
@@ -1261,12 +1168,6 @@ private:
 
 	bool m_searchDlgActive; /*!< True if search dialogue is active. */
 
-	QSet<QString> m_zfoFilesToImport; /*!< Set of files to be imported. */
-	int m_numFilesToImport;
-	QList< QPair<QString, QString> > m_importSucceeded,
-	                                 m_importExisted,
-	                                 m_importFailed;
-
 	int m_received_1;
 	int m_received_2;
 	int m_sent_1;
@@ -1279,10 +1180,19 @@ private:
 	QString m_on_export_zfo_activate;
 	QString m_on_import_database_dir_activate;
 	QString m_import_zfo_path;
-	bool isMainWindow;
+	QRect m_geometry; /* Non-maximised window geometry. */
 
 	QStringList m_msgTblAppendedCols; /*< Appended columns. */
 
+	QSet<QString> m_zfoFilesToImport; /*!< Set of files to be imported. */
+	int m_numFilesToImport; /*!< Input ZFO count. */
+	/*!< QPair in following lists means:
+	 * first string - zfo file name,
+	 * second = import result text */
+	QList< QPair<QString, QString> > m_importSucceeded; /*!< Success import resulty lists. */
+	QList< QPair<QString, QString> > m_importExisted; /*!< Import exists resulty lists. */
+	QList< QPair<QString, QString> > m_importFailed; /*!< Import error resulty lists. */
+
 	/* User interface elements. */
 	Ui::MainWindow *ui; /*!< User interface as generated from ui files. */
 	QLineEdit *mui_filterLine; /*!< Search filter line object. */
