@@ -563,8 +563,9 @@ bool DbMsgsTblModel::fillTagsColumn(const QString &userName, int col)
 
 	for (int row = 0; row < rowCount(); ++row) {
 		qint64 dmId = TblModel::index(row, 0).data().toLongLong();
-		m_data[row][col] = QVariant::fromValue(
-		    tagDb->getMessageTags(userName, dmId));
+		TagItemList tagList(tagDb->getMessageTags(userName, dmId));
+		tagList.sortNames();
+		m_data[row][col] = QVariant::fromValue(tagList);
 	}
 
 	emit dataChanged(TblModel::index(0, col),
@@ -608,8 +609,10 @@ bool DbMsgsTblModel::refillTagsColumn(const QString &userName,
 	for (int row = 0; row < rowCount(); ++row) {
 		qint64 dmId = TblModel::index(row, 0).data().toLongLong();
 		if (dmIds.contains(dmId)) {
-			m_data[row][col] = QVariant::fromValue(
+			TagItemList tagList(
 			    tagDb->getMessageTags(userName, dmId));
+			tagList.sortNames();
+			m_data[row][col] = QVariant::fromValue(tagList);
 			emit dataChanged(TblModel::index(row, col),
 			    TblModel::index(row, col));
 		}
