@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2015 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -91,6 +91,17 @@ signals:
 	void importZfoFinished(const QString &fileName, int result,
 	    const QString &resultDesc);
 
+	/*!
+	 * @brief Emitted when message import finishes.
+	 *
+	 * @param[in] userName      Account user name.
+	 * @param[in] errImportList List of unsuccess imports (description).
+	 * @param[in] totalMsg      Total number of messages.
+	 * @param[in] importedMsg   Total number of imported messages.
+	 */
+	void importMessageFinished(const QString &userName,
+	    const QStringList &errImportList, int totalMsgs, int importedMsgs);
+
 	/*!
 	 * @brief This signal is emitted when counted value is changed
 	 *
@@ -99,6 +110,13 @@ signals:
 	 */
 	void progressChange(const QString &label, int value);
 
+	/*!
+	 * @brief This signal is emitted when account is changed.
+	 *
+	 * @param[in] account username.
+	 */
+	void refreshAccountList(const QString &userName);
+
 	/*!
 	 * @brief Emitted when send message finishes.
 	 *
@@ -128,11 +146,11 @@ signals:
 	    const QStringList &resultList, const QString &errStr);
 
 	/*!
-	 * @brief This signal is emitted when account is changed.
+	 * @brief This signal is emitted when status bar text is changed
 	 *
-	 * @param[in] account username.
+	 * @param[in] text Status bar text.
 	 */
-	void refreshAccountList(const QString &userName);
+	void statusBarChange(const QString &text);
 };
 
 /*!
